@@ -17,7 +17,6 @@ from ..constants import (
     TIME_DIVISION,
     TEMPO,
     MIDI_INSTRUMENTS,
-    CHORD_MAPS,
     DRUM_PITCH_RANGE,
 )
 
@@ -69,7 +68,6 @@ class MuMIDI(MIDITokenizer):
         beat_res: Dict[Tuple[int, int], int] = BEAT_RES,
         nb_velocities: int = NB_VELOCITIES,
         additional_tokens: Dict[str, bool] = ADDITIONAL_TOKENS,
-        programs: List[int] = None,
         special_tokens: List[str] = SPECIAL_TOKENS,
         params: Union[str, Path] = None,
         drum_pitch_range: range = DRUM_PITCH_RANGE,
@@ -77,7 +75,7 @@ class MuMIDI(MIDITokenizer):
         additional_tokens["Rest"] = False
         additional_tokens["TimeSignature"] = False  # not compatible
         self.drum_pitch_range = drum_pitch_range
-        self.programs = list(range(-1, 128)) if programs is None else programs
+        self.programs = additional_tokens.get("programs", list(range(-1, 128)))
         # used in place of positional encoding
         self.max_bar_embedding = 60  # this attribute might increase during encoding
         self.vocab_types_idx = {
@@ -151,7 +149,7 @@ class MuMIDI(MIDITokenizer):
         * -2: Velocity
         * -1: Duration
 
-        :param midi: the MIDI objet to convert
+        :param midi: the MIDI object to convert
         :return: sequences of tokens
         """
         # Check if the durations values have been calculated before for this time division
@@ -329,8 +327,11 @@ class MuMIDI(MIDITokenizer):
         if self.additional_tokens["Chord"] and not track.is_drum:
             chords = detect_chords(
                 track.notes,
-                self.current_midi_metadata["time_division"],
-                self._first_beat_res,
+                self._current_midi_metadata["time_division"],
+                chord_maps=self.additional_tokens["chord_maps"],
+                specify_root_note=self.additional_tokens["chord_tokens_with_root_note"],
+                beat_res=self._first_beat_res,
+                unknown_chords_nb_notes_range=self.additional_tokens["chord_unknown"],
             )
             unsqueezed = []
             for c in range(len(chords)):
@@ -487,10 +488,7 @@ class MuMIDI(MIDITokenizer):
 
         # CHORD
         if self.additional_tokens["Chord"]:
-            vocab[0] += [
-                f"Chord_{i}" for i in range(3, 6)
-            ]  # non recognized chords (between 3 and 5 notes only)
-            vocab[0] += [f"Chord_{chord_quality}" for chord_quality in CHORD_MAPS]
+            vocab[0] += self._create_chords_tokens()
 
         # REST
         if self.additional_tokens["Rest"]:
